@@ -10,7 +10,7 @@ use ExtUtils::CBuilder::Base;
 use IO::File;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.24';
+$VERSION = '0.25';
 @ISA = qw(ExtUtils::CBuilder::Base);
 
 sub new {
@@ -347,7 +347,7 @@ sub format_linker_cmd {
   # Embed the manifest file for VC 2005 (aka VC 8) or higher, but not for the 64-bit Platform SDK compiler
   if ($cf->{ivsize} == 4 && $cf->{cc} eq 'cl' and $cf->{ccversion} =~ /^(\d+)/ and $1 >= 14) {
     push @cmds, [
-      'mt', '-nologo', $spec{manifest}, '-outputresource:' . "$output;2"
+      'if', 'exist', $spec{manifest}, 'mt', '-nologo', $spec{manifest}, '-outputresource:' . "$output;2"
     ];
   }
 
